@@ -1,3 +1,16 @@
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+# implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import logging
 
 from django import forms
@@ -16,20 +29,38 @@ LOG = logging.getLogger(__name__)
 class Login(AuthenticationForm):
     """ Form used for logging in a user.
 
-    Handles authentication with Keystone, choosing a tenant, and fetching
-    a scoped token token for that tenant.
+    Handles authentication with Keystone by providing the domain name, username
+    and password. A scoped token is fetched after successful authentication.
+
+    A domain name is required if authenticating with Keystone V3 running
+    multi-domain configuration.
+
+    If the user authenticated has a default project set, the token will be
+    automatically scoped to their default project.
+
+    If the user authenticated has no default project set, the authentication
+    backend will try to scope to the projects returned from the user's assigned
+    projects. The first successful project scoped will be returned.
 
     Inherits from the base ``django.contrib.auth.forms.AuthenticationForm``
     class for added security features.
     """
     region = forms.ChoiceField(label=_("Region"), required=False)
-    username = forms.CharField(label=_("User Name"))
+    username = forms.CharField(
+        label=_("User Name"),
+        widget=forms.TextInput(attrs={"autofocus": "autofocus"}))
     password = forms.CharField(label=_("Password"),
                                widget=forms.PasswordInput(render_value=False))
-    tenant = forms.CharField(required=False, widget=forms.HiddenInput())
 
     def __init__(self, *args, **kwargs):
         super(Login, self).__init__(*args, **kwargs)
+        self.fields.keyOrder = ['username', 'password', 'region']
+        if getattr(settings,
+                   'OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT',
+                    False):
+            self.fields['domain'] = forms.CharField(label=_("Domain"),
+                                                    required=True)
+            self.fields.keyOrder = ['domain', 'username', 'password', 'region']
         self.fields['region'].choices = self.get_region_choices()
         if len(self.fields['region'].choices) == 1:
             self.fields['region'].initial = self.fields['region'].choices[0][0]
@@ -42,13 +73,13 @@ class Login(AuthenticationForm):
 
     @sensitive_variables()
     def clean(self):
+        default_domain = getattr(settings,
+                                 'OPENSTACK_KEYSTONE_DEFAULT_DOMAIN',
+                                 'Default')
         username = self.cleaned_data.get('username')
         password = self.cleaned_data.get('password')
         region = self.cleaned_data.get('region')
-        tenant = self.cleaned_data.get('tenant')
-
-        if not tenant:
-            tenant = None
+        domain = self.cleaned_data.get('domain', default_domain)
 
         if not (username and password):
             # Don't authenticate, just let the other validators handle it.
@@ -58,7 +89,7 @@ class Login(AuthenticationForm):
             self.user_cache = authenticate(request=self.request,
                                            username=username,
                                            password=password,
-                                           tenant=tenant,
+                                           user_domain_name=domain,
                                            auth_url=region)
             msg = 'Login successful for user "%(username)s".' % \
                 {'username': username}
