@@ -1,3 +1,16 @@
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or
+# implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import requests
 import uuid
 
@@ -62,8 +75,8 @@ def generate_test_data():
                 'id': uuid.uuid4().hex
             },
             {
-                'url':'http://public.localhost:5000/v3',
-                'region':'RegionOne',
+                'url': 'http://public.localhost:5000/v3',
+                'region': 'RegionOne',
                 'interface': 'public',
                  'id': uuid.uuid4().hex
             }
@@ -94,7 +107,7 @@ def generate_test_data():
                      'domain_id': domain_dict['id'],
                      'enabled': True}
     project_dict_2 = {'id': uuid.uuid4().hex,
-                     'name': '',
+                     'name': 'tenant_two',
                      'description': '',
                      'domain_id': domain_dict['id'],
                      'enabled': False}
@@ -129,9 +142,9 @@ def generate_test_data():
                 'id': uuid.uuid4().hex
             },
             {
-                'url':'http://nova-public.localhost:8774/v2.0/%s' \
+                'url': 'http://nova-public.localhost:8774/v2.0/%s' \
                        % (project_dict_1['id']),
-                'region':'RegionOne',
+                'region': 'RegionOne',
                 'interface': 'public',
                  'id': uuid.uuid4().hex
             },
@@ -150,9 +163,9 @@ def generate_test_data():
                 'id': uuid.uuid4().hex
             },
             {
-                'url':'http://nova2-public.localhost:8774/v2.0/%s' \
+                'url': 'http://nova2-public.localhost:8774/v2.0/%s' \
                        % (project_dict_1['id']),
-                'region':'RegionTwo',
+                'region': 'RegionTwo',
                 'interface': 'public',
                  'id': uuid.uuid4().hex
             }
@@ -213,7 +226,6 @@ def generate_test_data():
                     'name': domain_dict['name']
                 }
             },
-            'roles': [role_dict],
             'catalog': [keystone_service]
         }
     }
